@@ -1,7 +1,9 @@
+from django.conf import settings
 from django.conf.urls import patterns, url, include
 
 from mpesa.dashboard.app import application as mpesa_dashboard_app
 from mpesa import views
+from mpesa.test_tools import views as test_views
 
 
 urlpatterns = patterns('',
@@ -9,3 +11,8 @@ urlpatterns = patterns('',
         name='mpesa-payment-details'),
     url(r'^dashboard/mpesa/', include(mpesa_dashboard_app.urls)),
 )
+
+if settings.DEBUG:
+    urlpatterns += patterns('',
+            url(r"^ipn-gen/$", test_views.IPNGeneratorView.as_view(), name="ipn-gen"),
+        )
\ No newline at end of file
